<?php

return [
    /*
    |--------------------------------------------------------------------------
    | Password Reset Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'reset'     => 'Лозинка је ресетована!',
    'sent'      => 'Послали смо ресет линк за вашу лозинку!',
    'throttled' => 'Молимо сачекајте пре него сто покушате поново.',
    'token'     => 'Укуцана ознака за ресетовање лозинке није важећа.',
    'user'      => 'Нисмо успели пронаћи корисника са емаил адресом.',
];
